Crate external_ip
source ·Expand description
Crate to figure out the system external IP
Structs
Consensus system that aggregates the various sources of information and returns the most common
reply
Consensus builder
DNS Source of the external ip
HTTP(s) Source of the external ip
IGD Source of the external ip
Enums
Traits
Interface for any kind of external ip source
Functions
Returns a collection of DNS sources to use to retrieve the external ip
Returns a collection of HTTP(s) sources to use to retrieve the external ip
For ease of use a single async function is enough to obtain the IP trying with all the default
sources enabled.
Returns a collection of all possible sources