pub enum Policy {
All,
First,
}Expand description
Policies for Consensus resolution
Variants
All
Requires all sources to be queried, it will ignore the sources returning errors but and it will return the IP with the most replies as the result.
First
Will test the sources one by one in order until there’s one success and will return it as the result.