Function external_ip::get_ip
source · pub async fn get_ip() -> Option<IpAddr>Expand description
For ease of use a single async function is enough to obtain the IP trying with all the default sources enabled.
pub async fn get_ip() -> Option<IpAddr>For ease of use a single async function is enough to obtain the IP trying with all the default sources enabled.