Struct external_ip::Consensus
source · pub struct Consensus { /* private fields */ }Expand description
Consensus system that aggregates the various sources of information and returns the most common reply
pub struct Consensus { /* private fields */ }Consensus system that aggregates the various sources of information and returns the most common reply