pub struct DNSSource { /* private fields */ }Expand description
DNS Source of the external ip
It expects a DNS server to target for a query (currently only A and TXT), to retrive in the reply of the message the IP. A few services are known for replying with the IP of the query sender.
Implementations