Function external_ip::get_ip
source · Expand description
For ease of use a single async function is enough to obtain the IP trying with all the default sources enabled.
For ease of use a single async function is enough to obtain the IP trying with all the default sources enabled.